@@ -1,18 +1,19 @@
 """Support Peewee ORM for Muffin framework."""
 
-import typing as t
+from typing import Callable, Optional, Type  # py37, py38: Type
 
-import muffin
 from aio_databases.database import ConnectionContext, Database, TransactionContext
+from muffin import Application
 from muffin.plugins import BasePlugin
 from peewee import Model
-from peewee_aio.manager import TMODEL, Manager
+from peewee_aio.manager import Manager
 from peewee_aio.model import AIOModel
+from peewee_aio.types import TVModel
 from peewee_migrate import Router
 
-from .fields import Choices, JSONField
+from .fields import Choices, JSONField  # noqa
 
-__version__ = "0.6.4"
+__version__ = "0.6.5"
 __project__ = "muffin-peewee-aio"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -21,9 +22,6 @@ __license__ = "MIT"
 __all__ = "Plugin", "JSONField", "Choices"
 
 
-assert JSONField and Choices
-
-
 class Plugin(BasePlugin):
 
     """Muffin Peewee Plugin."""
@@ -41,13 +39,13 @@ class Plugin(BasePlugin):
         "migrations_path": "migrations",
     }
 
-    router: Router = None
+    router: Router
     manager: Manager = Manager(
         "dummy://localhost"
     )  # Dummy manager for support registration
     database: Database
 
-    def setup(self, app: muffin.Application, **options):
+    def setup(self, app: Application, **options):
         """Init the plugin."""
         super().setup(app, **options)
 
@@ -57,7 +55,7 @@ class Plugin(BasePlugin):
             manager.register(model)
         self.manager = manager
         self.database = manager.aio_database
-        self.Model: t.Type[AIOModel] = self.manager.Model
+        self.Model: Type[AIOModel] = self.manager.Model
 
         if self.cfg.migrations_enabled:
             router = Router(manager.pw_database, migrate_dir=self.cfg.migrations_path)
@@ -65,7 +63,7 @@ class Plugin(BasePlugin):
 
             # Register migration commands
             @app.manage
-            def peewee_migrate(name: str = None, fake: bool = False):
+            def peewee_migrate(name: Optional[str] = None, fake: bool = False):
                 """Run application's migrations.
 
                 :param name: Choose a migration' name
@@ -107,7 +105,7 @@ class Plugin(BasePlugin):
                     self.router.clear()
 
             @app.manage
-            def peewee_merge(name: str = "initial", clear: bool = False):
+            def peewee_merge(name: str = "initial"):
                 """Merge all migrations into one."""
                 with manager.allow_sync():
                     self.router.merge(name)
@@ -132,7 +130,7 @@ class Plugin(BasePlugin):
         """Disconnect the database."""
         await self.database.disconnect()
 
-    def register(self, Model: t.Type[TMODEL]) -> t.Type[TMODEL]:
+    def register(self, Model: Type[TVModel]) -> Type[TVModel]:
         """Register a model with self manager."""
         return self.manager.register(Model)
 
@@ -142,24 +140,24 @@ class Plugin(BasePlugin):
     def transaction(self, *params, **opts) -> TransactionContext:
         return self.database.transaction(*params, **opts)
 
-    async def create_tables(self, *Models: t.Type[Model]):
+    async def create_tables(self, *Models: Type[Model]):
         """Create SQL tables."""
         await self.manager.create_tables(*(Models or self.manager.models))
 
-    async def drop_tables(self, *Models: t.Type[Model]):
+    async def drop_tables(self, *Models: Type[Model]):
         """Drop SQL tables."""
         await self.manager.drop_tables(*(Models or self.manager.models))
 
-    def get_middleware(self) -> t.Callable:
+    def get_middleware(self) -> Callable:
         """Generate a middleware to manage connection/transaction."""
 
-        async def middleware(handler, request, receive, send):  # type: ignore
+        async def middleware(handler, request, receive, send):
             async with self.connection():
                 return await handler(request, receive, send)
 
         if self.cfg.auto_transaction:
 
-            async def middleware(handler, request, receive, send):  # noqa
+            async def middleware(handler, request, receive, send):
                 async with self.connection():
                     async with self.transaction():
                         return await handler(request, receive, send)
